starcluster.image.EBSImageCreator

Package starcluster :: Module image :: Class EBSImageCreator |
[hide private]
[frames] | no frames]

# Class EBSImageCreator

source code

Creates a new EBS image from a running instance

If the instance is an instance-store image, then this class will create a new volume, attach it to the instance, sync the root filesystem to the volume, detach the volume, snapshot it, and then create a new AMI from the snapshot

If the instance is EBS-backed, this class simply calls ec2.create_image which tells Amazon to create a new image in a single API call.

Instance Methods | [hide private]
__init__(self, easy_ec2, instance_id, key_location, name, description=None, snapshot_description=None, kernel_id=None, ramdisk_id=None, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
create_image(*arg, **kargs) Raw timing function | source code
_create_image_from_ebs(self, size=15) | source code
_create_image_from_instance_store(self, size=15) | source code
Inherited from `ImageCreator`: `clean_private_data` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, easy_ec2, instance_id, key_location, name, description=None, snapshot_description=None, kernel_id=None, ramdisk_id=None, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### create_image(*arg, **kargs) | source code
Raw timing function Decorators: `@print_timing`